;;; ascii-display-03.el --- show ISO-8859-3 characters on ASCII terminals.

;; Copyright (C) 1987 Free Software Foundation, Inc.

;; Author: Sergei B. Porrovsky
;; Maintainer:
;; Keywords:

;; This file is part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Commentary:

;; This code sets up to display ASCIIzations of ISO 8859/3 characters
;;  on plain ASCII terminals.

;; Seven non-existant Latin3 holes (A5,AE,BE,C3,D0,E3,F0) have
;; been filled with their Latin1 equivalents

;;; Code:

(require 'disp-table)

;;;###autoload
(defun askiigu (arg)
  "Toggle ASCIIzed display of Esperantic characters encoded with ISO 8859-3.
When enabled, characters in the range of 160 to 255 display according to
cxirkavx-convention.
With prefix argument, enable ASCIIzation iff arg is positive."
  (interactive "P")
  (if (or (<= (prefix-numeric-value arg) 0)
	  (and (null arg)
	       (char-table-p standard-display-table)
	       (equal (aref standard-display-table 161) [161])))
      (progn
           (standard-display-underline ?{ ?{)   ; make true braces underlined
           (standard-display-underline ?} ?})   ; make true braces underlined

           (standard-display-ascii 160 "{_}")   ; NBSP (no-break space)
           (standard-display-ascii 161 "{~H}")  ; Hstroke
           (standard-display-ascii 162 "{)}")   ; breve
           (standard-display-ascii 163 "{Pd}")  ; pound sign
           (standard-display-ascii 164 "{$}")   ; general currency sign
           (standard-display-ascii 165 "{=Y}")  ; Yen sign (L1)
           (standard-display-ascii 166 "Hx")    ; Hcircumflex
           (standard-display-ascii 167 "{Se}")  ; section sign
           (standard-display-ascii 168 "{:}")   ; diaeresis
           (standard-display-ascii 169 "{.I}")  ; Idot
           (standard-display-ascii 170 "{,S}")  ; Scedilla
           (standard-display-ascii 171 "{)G}")  ; Gbreve
           (standard-display-ascii 172 "Jx")    ; Jcircumflex
           (standard-display-ascii 173 "{-}")   ; soft hyphen
           (standard-display-ascii 174 "(R)")   ; registered sign (L1)
           (standard-display-ascii 175 "{.Z}")  ; Zdot
           (standard-display-ascii 176 "{^0}")  ; degree sign
           (standard-display-ascii 177 "{~h}")  ; hstroke
           (standard-display-ascii 178 "{^2}")  ; superscript two
           (standard-display-ascii 179 "{^3}")  ; superscript three
           (standard-display-ascii 180 "{'}")   ; acute accent
           (standard-display-ascii 181 "{mu}")  ; micro sign
           (standard-display-ascii 182 "hx")    ; hcircumflex
           (standard-display-ascii 183 "{*}")   ; bullet
           (standard-display-ascii 184 "{,}")   ; cedilla
           (standard-display-ascii 185 "{i}")   ; dotless i
           (standard-display-ascii 186 "{,s}")  ; scedilla
           (standard-display-ascii 187 "{)g}")  ; gbreve
           (standard-display-ascii 188 "jx")    ; jcircumflex
           (standard-display-ascii 189 "{1/2}") ; fraction one-half
           (standard-display-ascii 190 "{3/4}") ; three-quarters (L1)
           (standard-display-ascii 191 "{.z}")  ; zdot
           (standard-display-ascii 192 "{`A}")  ; A with grave accent
           (standard-display-ascii 193 "{'A}")  ; A with acute accent
           (standard-display-ascii 194 "{^A}")  ; A with circumflex accent
           (standard-display-ascii 195 "{~A}")  ; A with tilde (L1)
           (standard-display-ascii 196 "{:A}")  ; A with umlaut mark
           (standard-display-ascii 197 "{.C}")  ; Cdot
           (standard-display-ascii 198 "Cx")    ; Ccircumflex
           (standard-display-ascii 199 "{,C}")  ; C with cedilla
           (standard-display-ascii 200 "{`E}")  ; E with grave accent
           (standard-display-ascii 201 "{'E}")  ; E with acute accent
           (standard-display-ascii 202 "{^E}")  ; E with circumflex accent
           (standard-display-ascii 203 "{:E}")  ; E with diaeresis mark
           (standard-display-ascii 204 "{`I}")  ; I with grave accent
           (standard-display-ascii 205 "{'I}")  ; I with acute accent
           (standard-display-ascii 206 "{^I}")  ; I with circumflex accent
           (standard-display-ascii 207 "{:I}")  ; I with umlaut mark
           (standard-display-ascii 208 "{~D}")  ; D with stroke, eth (L1)
           (standard-display-ascii 209 "{~N}")  ; N with tilde
           (standard-display-ascii 210 "{`O}")  ; O with grave accent
           (standard-display-ascii 211 "{'O}")  ; O with acute accent
           (standard-display-ascii 212 "{^O}")  ; O with circumflex accent
           (standard-display-ascii 213 "{.G}")  ; Gdot
           (standard-display-ascii 214 "{:O}")  ; O with umlaut mark
           (standard-display-ascii 215 "{x}")   ; multiplication sign
           (standard-display-ascii 216 "Gx")    ; Gcircumflex
           (standard-display-ascii 217 "{`U}")  ; U with grave accent
           (standard-display-ascii 218 "{'U}")  ; U with acute accent
           (standard-display-ascii 219 "{^U}")  ; U with circumflex accent
           (standard-display-ascii 220 "{:U}")  ; U with umlaut mark
           (standard-display-ascii 221 "Ux")    ; Ubreve
           (standard-display-ascii 222 "Sx")    ; Scircumflex
           (standard-display-ascii 223 "{ss}")  ; small sharp s, German
           (standard-display-ascii 224 "{`a}")  ; a with grave accent
           (standard-display-ascii 225 "{'a}")  ; a with acute accent
           (standard-display-ascii 226 "{^a}")  ; a with circumflex accent
           (standard-display-ascii 227 "{~a}")  ; a with tilde (L1)
           (standard-display-ascii 228 "{:a}")  ; a with umlaut mark
           (standard-display-ascii 229 "{.c}")  ; cdot
           (standard-display-ascii 230 "cx")    ; ccircumflex
           (standard-display-ascii 231 "{,c}")  ; c with cedilla
           (standard-display-ascii 232 "{`e}")  ; e with grave accent
           (standard-display-ascii 233 "{'e}")  ; e with acute accent
           (standard-display-ascii 234 "{^e}")  ; e with circumflex accent
           (standard-display-ascii 235 "{:e}")  ; e with diaeresis mark
           (standard-display-ascii 236 "{`i}")  ; i with grave accent
           (standard-display-ascii 237 "{'i}")  ; i with acute accent
           (standard-display-ascii 238 "{^i}")  ; i with circumflex accent
           (standard-display-ascii 239 "{:i}")  ; i with diaeresis mark
           (standard-display-ascii 240 "{-d}")  ; d with stroke, eth (L1)
           (standard-display-ascii 241 "{~n}")  ; n with tilde
           (standard-display-ascii 242 "{`o}")  ; o with grave accent
           (standard-display-ascii 243 "{'o}")  ; o with acute accent
           (standard-display-ascii 244 "{^o}")  ; o with circumflex accent
           (standard-display-ascii 245 "{.g}")  ; gdot
           (standard-display-ascii 246 "{:o}")  ; o with umlaut mark
           (standard-display-ascii 247 "{/}")   ; division sign
           (standard-display-ascii 248 "gx")    ; gcircumflex
           (standard-display-ascii 249 "{`u}")  ; u with grave accent
           (standard-display-ascii 250 "{'u}")  ; u with acute accent
           (standard-display-ascii 251 "{^u}")  ; u with circumflex accent
           (standard-display-ascii 252 "{:u}")  ; u with umlaut
           (standard-display-ascii 253 "vx")    ; ubreve
;          (standard-display-underline 253 117) ; ubreve
           (standard-display-ascii 254 "sx")    ; scircumflex
           (standard-display-ascii 255 "{.}")   ; dot accent
      )
      (progn
           (standard-display-default ?{ ?})
           (standard-display-european t)
      )
  )
)

(provide 'ascii-display-03)

;;; ascii-display-03.el ends here
